@@ -147,8 +147,6 @@ class ClusterAdsorbateCoverage(object):
         self.surf_ids = cas.surf_ids
         self.label_dict = cas.label_dict 
         self.hetero_site_list = deepcopy(cas.site_list)
-        self.unique_sites = cas.get_unique_sites(unique_composition=
-                                                 self.composition_effect) 
 
         self.label_list = ['0'] * len(self.hetero_site_list)
         self.populate_occupied_sites()
@@ -426,7 +424,7 @@ class ClusterAdsorbateCoverage(object):
 
         return sorted(labs)
 
-    def get_graph(self, fragmentation=True):                                         
+    def get_graph(self, fragmentation=True, subsurf_effect=False):                                         
         """Get the graph representation of the nanoparticle with adsorbates.
 
         Parameters
@@ -436,12 +434,19 @@ class ClusterAdsorbateCoverage(object):
             that multidentate species with different orientations have 
             different graphs.
 
+        subsurf_effect : bool, default False
+            Take subsurface atoms into consideration when genearting graph. 
+
         """
 
         hsl = self.hetero_site_list
         hcm = self.cas.get_connectivity().copy()
-        surfhcm = hcm[self.surf_ids]
-        symbols = self.symbols[self.surf_ids]
+        if subsurf_effect:
+            surf_ids = self.surf_ids + self.cas.get_subsurface()
+        else:
+            surf_ids = self.surf_ids
+        surfhcm = hcm[surf_ids]
+        symbols = self.symbols[surf_ids]
         nrows, ncols = surfhcm.shape       
         newrows, frag_list = [], []
         for st in hsl:
@@ -467,7 +472,7 @@ class ClusterAdsorbateCoverage(object):
                          [(j + nrows, {'symbol': frag_list[j]})
                            for j in range(len(frag_list))])
         # Add edges from surface connectivity matrix
-        shcm = surfhcm[:,self.surf_ids]
+        shcm = surfhcm[:,surf_ids]
         shcm = shcm * np.tri(*shcm.shape, k=-1)
         rows, cols = np.where(shcm == 1)
         edges = zip(rows.tolist(), cols.tolist())
@@ -629,8 +634,6 @@ class SlabAdsorbateCoverage(object):
         self.connectivity_matrix = sas.connectivity_matrix
         self.label_dict = sas.label_dict 
         self.hetero_site_list = deepcopy(sas.site_list)
-        self.unique_sites = sas.get_unique_sites(unique_composition=
-                                                 self.composition_effect) 
 
         self.label_list = ['0'] * len(self.hetero_site_list)
         self.populate_occupied_sites()
@@ -908,7 +911,7 @@ class SlabAdsorbateCoverage(object):
 
         return sorted(labs)
 
-    def get_graph(self, fragmentation=True):                                         
+    def get_graph(self, fragmentation=True, subsurf_effect=False):                                         
         """Get the graph representation of the nanoparticle with adsorbates.
 
         Parameters
@@ -918,12 +921,19 @@ class SlabAdsorbateCoverage(object):
             that multidentate species with different orientations have 
             different graphs.
 
+        subsurf_effect : bool, default False
+            Take subsurface atoms into consideration when genearting graph. 
+
         """
 
         hsl = self.hetero_site_list
         hcm = self.connectivity_matrix.copy()
-        surfhcm = hcm[self.surf_ids]
-        symbols = self.symbols[self.surf_ids]
+        if subsurf_effect:
+            surf_ids = self.surf_ids + self.subsurf_ids
+        else:
+            surf_ids = self.surf_ids
+        surfhcm = hcm[surf_ids]
+        symbols = self.symbols[surf_ids]
         nrows, ncols = surfhcm.shape       
         newrows, frag_list = [], []
         for st in hsl:
@@ -950,7 +960,7 @@ class SlabAdsorbateCoverage(object):
                            for j in range(len(frag_list))])
 
         # Add edges from surface connectivity matrix
-        shcm = surfhcm[:,self.surf_ids]
+        shcm = surfhcm[:,surf_ids]
         shcm = shcm * np.tri(*shcm.shape, k=-1)
         rows, cols = np.where(shcm == 1)
         edges = zip(rows.tolist(), cols.tolist())
